Trivial patch: fix typos, wrong log domain in DHCPv4



Hi,

feel free to apply (diff against 0.9.6.4)

Regards,

Stefan

-- 
Stefan Brüns  /  Bergstraße 21  /  52062 Aachen
phone: +49 241 53809034     mobile: +49 151 50412019
diff --git a/src/nm-device.c b/src/nm-device.c
index cfd3ba5..01def54 100644
--- a/src/nm-device.c
+++ b/src/nm-device.c
@@ -1550,7 +1550,7 @@ dhcp4_lease_change (NMDevice *device, NMIP4Config *config)
 	nm_utils_merge_ip4_config (config, nm_connection_get_setting_ip4_config (connection));
 
 	if (!nm_device_set_ip4_config (device, config, FALSE, &reason)) {
-		nm_log_warn (LOGD_DHCP6, "(%s): failed to update IPv4 config in response to DHCP event.",
+		nm_log_warn (LOGD_DHCP4, "(%s): failed to update IPv4 config in response to DHCP event.",
 		             nm_device_get_ip_iface (device));
 		nm_device_state_changed (device, NM_DEVICE_STATE_FAILED, reason);
 		return;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libnm-util/nm-setting-ip4-config.c b/libnm-util/nm-setting-ip4-config.c
index 5dc9199..9e7e99a 100644
--- a/libnm-util/nm-setting-ip4-config.c
+++ b/libnm-util/nm-setting-ip4-config.c
@@ -996,7 +996,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 	 * List of DNS servers (network byte order).  For the 'auto' method, these
 	 * DNS servers are appended to those (if any) returned by automatic
 	 * configuration.  DNS servers cannot be used with the 'shared', 'link-local',
 	 * or 'disabled' methods as there is no usptream network.  In all other
 	 * methods, these DNS servers are used as the only DNS servers for this
 	 * connection.
 	 **/
@@ -1009,7 +1009,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 							   "appended to those (if any) returned by automatic "
 							   "configuration.  DNS servers cannot be used with "
 							   "the 'shared', 'link-local', or 'disabled' "
-							   "methods as there is no usptream network.  In all "
+							   "methods as there is no upstream network.  In all "
 							   "other methods, these DNS servers are used as the "
 							   "only DNS servers for this connection.",
 							   DBUS_TYPE_G_UINT_ARRAY,
@@ -1143,7 +1143,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 	 * NMSettingIP4Config:dhcp-client-id:
 	 *
 	 * A string sent to the DHCP server to identify the local machine which the
 	 * DHCP server may use to cusomize the DHCP lease and options.
 	 **/
 	g_object_class_install_property
 		(object_class, PROP_DHCP_CLIENT_ID,
@@ -1151,7 +1151,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 						   "DHCP Client ID",
 						   "A string sent to the DHCP server to identify the "
 						   "local machine which the DHCP server may use to "
-						   "cusomize the DHCP lease and options.",
+						   "customize the DHCP lease and options.",
 						   NULL,
 						   G_PARAM_READWRITE | NM_SETTING_PARAM_SERIALIZE));
 
@@ -996,7 +996,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 	 * DNS servers are appended to those (if any) returned by automatic
 	 * configuration.  DNS servers cannot be used with the 'shared', 'link-local',
-	 * or 'disabled' methods as there is no usptream network.  In all other
+	 * or 'disabled' methods as there is no upstream network.  In all other
 	 * methods, these DNS servers are used as the only DNS servers for this
 	 * connection.
@@ -1143,7 +1143,7 @@ nm_setting_ip4_config_class_init (NMSettingIP4ConfigClass *setting_class)
 	 *
 	 * A string sent to the DHCP server to identify the local machine which the
-	 * DHCP server may use to cusomize the DHCP lease and options.
+	 * DHCP server may use to customize the DHCP lease and options.
 	 **/
 	g_object_class_install_property